"""测试：配置加载与命令分析，不依赖真实 Redis。"""
import pytest


def test_parse_command():
    from redis_client_mcp.command_analysis import parse_command, analyze_command
    assert parse_command("GET foo") == ("GET", ["foo"])
    assert parse_command("  SET   k   v  ") == ("SET", ["k", "v"])
    assert parse_command("INFO server") == ("INFO", ["server"])
    assert parse_command("") == ("", [])


def test_analyze_command_read():
    from redis_client_mcp.command_analysis import analyze_command
    a = analyze_command("GET mykey", read_only=False)
    assert a.command == "GET"
    assert a.is_read is True
    assert a.is_write is False
    assert a.need_confirm is False
    a2 = analyze_command("INFO memory", read_only=False)
    assert a2.is_read is True


def test_analyze_command_write():
    from redis_client_mcp.command_analysis import analyze_command
    a = analyze_command("SET k v", read_only=False)
    assert a.command == "SET"
    assert a.is_write is True
    assert a.need_confirm is True
    a_ro = analyze_command("SET k v", read_only=True)
    assert "只读" in a_ro.message


def test_analyze_command_dangerous():
    from redis_client_mcp.command_analysis import analyze_command
    a = analyze_command("FLUSHALL", read_only=False)
    assert a.is_dangerous is True
    assert "禁止" in a.message or "危险" in a.message


def test_config_single(monkeypatch):
    monkeypatch.setenv("REDIS_HOST", "localhost")
    monkeypatch.setenv("REDIS_PORT", "6379")
    from redis_client_mcp.config import load_connection_map
    default, cmap, name = load_connection_map()
    assert default.host == "localhost"
    assert default.port == 6379
    assert default.mode == "standalone"
    assert "default" in cmap
    assert name == "default"


def test_config_profiles(monkeypatch):
    monkeypatch.setenv(
        "TEST_REDIS_PROFILES",
        '[{"mode":"standalone","host":"r1","port":6379,"password":"p"},{"mode":"cluster","hosts":["c1:6379","c2:6379"],"name":"cache"}]',
    )
    monkeypatch.setenv("PROD_REDIS_PROFILES", '[{"host":"prod","port":6379}]')
    from redis_client_mcp.config import load_connection_map
    default, cmap, name = load_connection_map()
    assert "test_0" in cmap
    assert cmap["test_0"].mode == "standalone"
    assert "test_cache" in cmap
    assert cmap["test_cache"].mode == "cluster"
    assert name == "prod_0"
    assert default.host == "prod"



"""
配置加载：Redis 连接（单机/集群）、安全与行为配置。
"""
from __future__ import annotations

import os
import sys
import json
from dataclasses import dataclass
from typing import Literal


@dataclass
class ConnectionConfig:
    """单条 Redis 连接配置"""
    mode: Literal["standalone", "cluster"]
    host: str
    port: int
    password: str = ""
    db: int = 0
    description: str | None = None
    # 集群时使用，standalone 忽略
    hosts: list[str] | None = None  # ["host1:6379", "host2:6379"]


@dataclass
class SafetyConfig:
    """安全与行为配置（全局）"""
    read_only: bool = False
    max_scan_keys: int = 1000  # SCAN 单次最多返回 key 数量
    confirm_dangerous: bool = True  # 危险命令需 confirm
    command_timeout_seconds: int = 30


def _parse_bool(val: str | None) -> bool:
    if val is None:
        return False
    return str(val).strip().lower() in ("1", "true", "yes", "on")


def _parse_int(val: str | int | None, default: int) -> int:
    if val is None:
        return default
    if isinstance(val, int):
        return val
    try:
        return int((val or "").strip())
    except (ValueError, AttributeError):
        return default


def load_safety_config() -> SafetyConfig:
    """从环境变量加载安全配置"""
    return SafetyConfig(
        read_only=_parse_bool(os.environ.get("REDIS_READ_ONLY")),
        max_scan_keys=_parse_int(os.environ.get("REDIS_MAX_SCAN_KEYS"), 1000),
        confirm_dangerous=_parse_bool(os.environ.get("REDIS_CONFIRM_DANGEROUS")) or True,
        command_timeout_seconds=_parse_int(os.environ.get("REDIS_COMMAND_TIMEOUT_SECONDS"), 30),
    )


def load_connection_map() -> tuple[ConnectionConfig, dict[str, ConnectionConfig], str]:
    """
    加载 Redis 连接配置。
    优先: TEST_REDIS_PROFILES / UAT_REDIS_PROFILES / PROD_REDIS_PROFILES（JSON 数组）。
    否则: REDIS_HOST, REDIS_PORT, REDIS_PASSWORD 单连接。
    返回: (default_connection, connection_map, default_profile_name)
    """
    connection_map: dict[str, ConnectionConfig] = {}
    default_profile_name = "default"
    default: ConnectionConfig | None = None

    # 优先: 按环境的数组
    for env in ("test", "uat", "prod"):
        key = f"{env.upper()}_REDIS_PROFILES"
        arr_json = os.environ.get(key)
        if not arr_json:
            continue
        try:
            arr = json.loads(arr_json)
            if not isinstance(arr, list):
                continue
            for i, v in enumerate(arr):
                if not isinstance(v, dict):
                    continue
                mode = (v.get("mode") or "standalone")
                if mode not in ("standalone", "cluster"):
                    mode = "standalone"
                password = str(v.get("password", "") or "")
                desc = v.get("description")
                description = (str(desc).strip() or None) if desc is not None else None
                port = _parse_int(v.get("port"), 6379)
                db = _parse_int(v.get("db"), 0)
                if mode == "standalone":
                    host = str(v.get("host", "")).strip()
                    if not host:
                        continue
                    conn = ConnectionConfig(
                        mode="standalone",
                        host=host,
                        port=port,
                        password=password,
                        db=db,
                        description=description,
                        hosts=None,
                    )
                else:
                    hosts_val = v.get("hosts")
                    if isinstance(hosts_val, list) and hosts_val:
                        hosts = [str(h).strip() for h in hosts_val if h]
                    else:
                        host = str(v.get("host", "")).strip()
                        if host:
                            hosts = [f"{host}:{port}"]
                        else:
                            continue
                    if not hosts:
                        continue
                    conn = ConnectionConfig(
                        mode="cluster",
                        host=hosts[0].split(":")[0] if ":" in hosts[0] else hosts[0],
                        port=port,
                        password=password,
                        db=0,
                        description=description,
                        hosts=hosts,
                    )
                sub_name = (v.get("name") or "").strip() or str(i)
                profile_key = f"{env}_{sub_name}" if sub_name != str(i) else f"{env}_{i}"
                connection_map[profile_key] = conn
        except json.JSONDecodeError:
            pass

    if connection_map:
        prod_keys = [k for k in connection_map if k.startswith("prod_")]
        if prod_keys:
            default_profile_name = prod_keys[0]
            default = connection_map[default_profile_name]
        else:
            default_profile_name = next(iter(connection_map))
            default = connection_map[default_profile_name]
        return default, connection_map, default_profile_name

    # 单连接
    host = os.environ.get("REDIS_HOST", "").strip()
    port = _parse_int(os.environ.get("REDIS_PORT"), 6379)
    password = os.environ.get("REDIS_PASSWORD", "")
    db = _parse_int(os.environ.get("REDIS_DB"), 0)
    if not host:
        print(
            "错误: 缺少 REDIS_HOST。多环境请配置 TEST_REDIS_PROFILES / UAT_REDIS_PROFILES / PROD_REDIS_PROFILES",
            file=sys.stderr,
        )
        sys.exit(1)
    default = ConnectionConfig(
        mode="standalone",
        host=host,
        port=port,
        password=password or "",
        db=db,
        description=None,
        hosts=None,
    )
    connection_map["default"] = default
    default_profile_name = "default"
    return default, connection_map, default_profile_name



"""
Redis 命令解析与安全检查：分类（只读/写/危险）、是否需 confirm。
"""
from __future__ import annotations

from dataclasses import dataclass

# 只读命令（不修改数据）
READ_ONLY = frozenset({
    "GET", "MGET", "GETRANGE", "GETSET",  # 若视为写则可移出
    "EXISTS", "TYPE", "TTL", "PTTL", "OBJECT",
    "SCAN", "HSCAN", "SSCAN", "ZSCAN",
    "HGET", "HGETALL", "HMGET", "HKEYS", "HVALS", "HLEN", "HEXISTS",
    "LRANGE", "LLEN", "LINDEX",
    "SMEMBERS", "SISMEMBER", "SCARD", "SRANDMEMBER",
    "ZRANGE", "ZRANGEBYSCORE", "ZRANK", "ZREVRANK", "ZCARD", "ZSCORE", "ZCOUNT",
    "INFO", "PING", "TIME", "DBSIZE", "KEYS",  # KEYS 只读但危险（阻塞）
})

# 危险命令：禁止或必须 confirm
DANGEROUS = frozenset({
    "FLUSHALL", "FLUSHDB", "KEYS",  # KEYS 大 key 会阻塞
    "CONFIG", "DEBUG", "SHUTDOWN", "BGREWRITEAOF", "BGSAVE",
    "CLUSTER", "MODULE", "REPLICAOF", "SAVE", "LASTSAVE",
})

# 写命令（修改数据）
WRITE = frozenset({
    "SET", "SETEX", "SETNX", "PSETEX", "GETDEL", "GETEX",
    "DEL", "UNLINK", "EXPIRE", "PEXPIRE", "EXPIREAT", "PEXPIREAT", "PERSIST",
    "INCR", "DECR", "INCRBY", "DECRBY", "INCRBYFLOAT", "APPEND",
    "HSET", "HSETNX", "HMSET", "HDEL", "HINCRBY", "HINCRBYFLOAT",
    "LPUSH", "RPUSH", "LPOP", "RPOP", "LREM", "LSET", "LTRIM", "RPOPLPUSH", "LMOVE", "BLMOVE",
    "SADD", "SREM", "SPOP", "SINTERSTORE", "SUNIONSTORE", "SDIFFSTORE", "SMOVE",
    "ZADD", "ZREM", "ZINCRBY", "ZPOPMIN", "ZPOPMAX", "ZREMRANGEBYRANK", "ZREMRANGEBYSCORE", "ZREMRANGEBYLEX",
    "RENAME", "RENAMENX", "COPY", "RESTORE", "MIGRATE",
    "PUBLISH", "SCRIPT", "EVAL", "EVALSHA",
})


@dataclass
class CommandAnalysis:
    """单条命令分析结果"""
    command: str
    args: list[str]
    is_read: bool
    is_write: bool
    is_dangerous: bool
    need_confirm: bool
    message: str


def normalize_command(cmd: str) -> str:
    """命令名转大写。"""
    return (cmd or "").strip().upper()


def parse_command(payload: str) -> tuple[str, list[str]]:
    """
    简单解析：首词为命令，其余为参数。
    若 payload 为 "GET foo" 返回 ("GET", ["foo"])；"SET k v" 返回 ("SET", ["k", "v"])。
    """
    parts = (payload or "").strip().split()
    if not parts:
        return "", []
    return normalize_command(parts[0]), parts[1:]


def analyze_command(payload: str, read_only: bool) -> CommandAnalysis:
    """
    分析一条 Redis 命令（由大模型产生），返回是否只读、是否危险、是否需要 confirm。
    """
    command, args = parse_command(payload)
    if not command:
        return CommandAnalysis(
            command="",
            args=[],
            is_read=False,
            is_write=False,
            is_dangerous=False,
            need_confirm=True,
            message="空命令，不执行。",
        )
    is_read = command in READ_ONLY and command not in DANGEROUS
    is_write = command in WRITE
    is_dangerous = command in DANGEROUS
    need_confirm = False
    message = ""
    if read_only and (is_write or is_dangerous):
        need_confirm = False
        message = "当前为只读模式，拒绝执行写操作或危险命令。"
    elif is_dangerous:
        if command == "KEYS":
            message = "KEYS 可能阻塞，建议使用 SCAN；若确需执行请传入 confirm=true。"
            need_confirm = True
        else:
            message = f"{command} 为危险命令，禁止通过 MCP 执行，请在 Redis 客户端中手动操作。"
            need_confirm = False  # 直接禁止
    elif is_write:
        message = "写操作，需传入 confirm=true 后执行。"
        need_confirm = True
    elif is_read:
        message = "只读命令，可直接执行。"
    else:
        message = f"未识别的命令 {command}，需传入 confirm=true 后执行。"
        need_confirm = True
    return CommandAnalysis(
        command=command,
        args=args,
        is_read=is_read,
        is_write=is_write,
        is_dangerous=is_dangerous,
        need_confirm=need_confirm,
        message=message,
    )



"""
Redis 连接封装：单机 Redis、集群 RedisCluster，统一接口。
"""
from __future__ import annotations

import contextlib
from typing import Any, Generator

from redis import Redis
from redis.cluster import RedisCluster
from redis.connection import ConnectionPool

from .config import ConnectionConfig, SafetyConfig


def get_connection_config(
    profile: str | None,
    default: ConnectionConfig,
    connection_map: dict[str, ConnectionConfig],
) -> ConnectionConfig:
    """解析 profile，返回对应连接配置。"""
    if not (profile or "").strip():
        return default
    key = (profile or "").strip()
    if key not in connection_map:
        raise ValueError(f"未知的 connection profile: {profile}，可用: {', '.join(sorted(connection_map))}")
    return connection_map[key]


@contextlib.contextmanager
def connect(
    config: ConnectionConfig,
    safety: SafetyConfig,
) -> Generator[Redis | RedisCluster, None, None]:
    """创建 Redis 或 RedisCluster 连接。"""
    if config.mode == "standalone":
        client = Redis(
            host=config.host,
            port=config.port,
            password=config.password or None,
            db=config.db,
            socket_connect_timeout=safety.command_timeout_seconds,
            socket_timeout=safety.command_timeout_seconds,
            decode_responses=True,
        )
    else:
        # cluster: hosts 格式 ["host:port", ...]
        startup_nodes = []
        for h in config.hosts or []:
            if ":" in h:
                host, _, port_str = h.rpartition(":")
                try:
                    port = int(port_str)
                except ValueError:
                    port = config.port
            else:
                host, port = h, config.port
            startup_nodes.append({"host": host.strip(), "port": port})
        if not startup_nodes:
            startup_nodes = [{"host": config.host, "port": config.port}]
        client = RedisCluster(
            startup_nodes=startup_nodes,
            password=config.password or None,
            decode_responses=True,
        )
    try:
        yield client
    finally:
        client.close()


def list_keys(
    client: Redis | RedisCluster,
    pattern: str = "*",
    max_keys: int = 1000,
) -> list[str]:
    """使用 SCAN 列出 key，不超过 max_keys。"""
    keys: list[str] = []
    cursor = 0
    while True:
        cursor, batch = client.scan(cursor=cursor, match=pattern, count=100)
        for k in batch:
            keys.append(k)
            if len(keys) >= max_keys:
                return keys
        if cursor == 0:
            break
    return keys


def info_sections(client: Redis | RedisCluster, section: str | None = None) -> dict[str, Any]:
    """INFO 命令，section 可选（server, memory, clients 等），None 表示 all。"""
    if section:
        return client.info(section) or {}
    return client.info() or {}


def execute_command(
    client: Redis | RedisCluster,
    *args: Any,
) -> Any:
    """执行一条 Redis 命令，返回结果。调用方负责安全检查。"""
    return client.execute_command(*args)



#!/usr/bin/env python3
"""
Redis MCP Server - 单机 + 集群

- 元数据：list_connections, list_keys, info
- 命令分析：analyze_command（不执行）
- 执行：execute_command（单条，由大模型产生；MCP 只做安全检查与执行）
"""

from __future__ import annotations

import sys
from collections.abc import AsyncIterator
from contextlib import asynccontextmanager
from dataclasses import dataclass
from typing import Annotated, Any, Optional

from mcp.server.fastmcp import FastMCP
from pydantic import BaseModel, Field

from .client import (
    connect,
    execute_command as _execute_command,
    get_connection_config,
    info_sections,
    list_keys as _list_keys,
)
from .config import ConnectionConfig, SafetyConfig, load_connection_map, load_safety_config
from .command_analysis import analyze_command as analyze_command_impl, parse_command

# ============== 配置加载 ==============

DEFAULT_CONN, CONNECTION_MAP, DEFAULT_PROFILE_NAME = load_connection_map()
SAFETY = load_safety_config()


@dataclass
class RedisState:
    default_connection: ConnectionConfig
    connection_map: dict[str, ConnectionConfig]
    default_profile_name: str
    safety: SafetyConfig


@asynccontextmanager
async def lifespan(app: FastMCP) -> AsyncIterator[RedisState]:
    state = RedisState(
        default_connection=DEFAULT_CONN,
        connection_map=CONNECTION_MAP,
        default_profile_name=DEFAULT_PROFILE_NAME,
        safety=SAFETY,
    )
    print("Redis MCP Server 已启动", file=sys.stderr)
    print(f"  默认 profile: {DEFAULT_PROFILE_NAME}", file=sys.stderr)
    print(f"  可用 profile: {', '.join(sorted(CONNECTION_MAP))}", file=sys.stderr)
    yield state
    print("Redis MCP Server 已关闭", file=sys.stderr)


mcp = FastMCP("Redis", lifespan=lifespan)


# ============== 数据模型 ==============

class ConnectionItem(BaseModel):
    profile: str = Field(description="profile 名")
    description: Optional[str] = Field(default=None, description="可选说明")
    mode: str = Field(description="standalone / cluster")


class ConnectionList(BaseModel):
    connections: list[ConnectionItem] = Field(description="可用连接列表")
    default: str = Field(description="默认 profile 名")


class KeyList(BaseModel):
    connection: str = Field(description="profile 名")
    pattern: str = Field(description="匹配模式")
    keys: list[str] = Field(description="key 列表")
    count: int = Field(description="数量")
    truncated: bool = Field(default=False, description="是否被 max_scan_keys 截断")


class InfoResult(BaseModel):
    connection: str = Field(description="profile 名")
    section: Optional[str] = Field(default=None, description="INFO 区段")
    data: dict[str, Any] = Field(description="INFO 返回的数据")


class CommandAnalysisResult(BaseModel):
    command: str = Field(description="命令名")
    args: list[str] = Field(description="参数列表")
    is_read: bool = Field(description="是否只读")
    is_write: bool = Field(description="是否写")
    is_dangerous: bool = Field(description="是否危险命令")
    need_confirm: bool = Field(description="是否需要 confirm 后执行")
    message: str = Field(description="说明")


class ExecuteCommandResult(BaseModel):
    command: str = Field(description="执行的命令")
    result: Any = Field(description="返回结果（可转为 JSON 兼容类型）")
    message: str = Field(default="", description="附加说明")


def _get_state() -> RedisState:
    return mcp.get_context().request_context.lifespan_context


def _conn(profile: Optional[str]) -> ConnectionConfig:
    state = _get_state()
    return get_connection_config(profile, state.default_connection, state.connection_map)


# ============== Tools ==============

@mcp.tool()
def list_connections() -> ConnectionList:
    """列出所有可用 Redis 连接（profile、说明、单机/集群）。"""
    state = _get_state()
    items = [
        ConnectionItem(
            profile=k,
            description=getattr(c, "description", None),
            mode=c.mode,
        )
        for k, c in sorted(state.connection_map.items())
    ]
    return ConnectionList(connections=items, default=state.default_profile_name)


@mcp.tool()
def list_keys(
    pattern: Annotated[str, Field(description="key 匹配模式，如 * 或 user:*")] = "*",
    connection: Annotated[Optional[str], Field(description="profile 名")] = None,
) -> KeyList:
    """使用 SCAN 列出 key，不超过配置的 max_scan_keys。"""
    state = _get_state()
    config = _conn(connection)
    profile_name = (connection or "").strip() or state.default_profile_name
    with connect(config, state.safety) as client:
        keys = _list_keys(client, pattern=pattern, max_keys=state.safety.max_scan_keys)
    truncated = len(keys) >= state.safety.max_scan_keys
    return KeyList(
        connection=profile_name,
        pattern=pattern,
        keys=keys,
        count=len(keys),
        truncated=truncated,
    )


@mcp.tool()
def info(
    section: Annotated[Optional[str], Field(description="INFO 区段，如 server/memory/clients，空为全部")] = None,
    connection: Annotated[Optional[str], Field(description="profile 名")] = None,
) -> InfoResult:
    """返回 Redis INFO 信息。"""
    state = _get_state()
    config = _conn(connection)
    profile_name = (connection or "").strip() or state.default_profile_name
    with connect(config, state.safety) as client:
        data = info_sections(client, section)
    return InfoResult(connection=profile_name, section=section, data=data)


@mcp.tool()
def analyze_command(
    command_payload: Annotated[str, Field(description="一条 Redis 命令，如 GET foo 或 SET k v")],
) -> CommandAnalysisResult:
    """分析一条 Redis 命令（不执行）：是否只读/写/危险，是否需要 confirm。"""
    state = _get_state()
    a = analyze_command_impl(command_payload.strip(), state.safety.read_only)
    return CommandAnalysisResult(
        command=a.command,
        args=a.args,
        is_read=a.is_read,
        is_write=a.is_write,
        is_dangerous=a.is_dangerous,
        need_confirm=a.need_confirm,
        message=a.message,
    )


def _serialize_result(v: Any) -> Any:
    """将 Redis 返回转为 JSON 友好类型。"""
    if v is None or isinstance(v, (bool, int, float, str)):
        return v
    if isinstance(v, bytes):
        return v.decode("utf-8", errors="replace")
    if isinstance(v, (list, tuple)):
        return [_serialize_result(x) for x in v]
    if isinstance(v, dict):
        return {str(k): _serialize_result(x) for k, x in v.items()}
    return str(v)


@mcp.tool()
def execute_command(
    command_payload: Annotated[str, Field(description="单条 Redis 命令，由大模型产生，如 GET key 或 SET k v")],
    confirm: Annotated[Optional[bool], Field(description="写操作或需确认的命令必须为 true")] = None,
    connection: Annotated[Optional[str], Field(description="profile 名")] = None,
) -> ExecuteCommandResult:
    """执行单条 Redis 命令。命令内容由大模型产生；MCP 只做安全检查与执行。写操作需 confirm=true。"""
    state = _get_state()
    payload = (command_payload or "").strip()
    if not payload:
        return ExecuteCommandResult(command="", result=None, message="空命令，不执行。")
    a = analyze_command_impl(payload, state.safety.read_only)
    if state.safety.read_only and (a.is_write or a.is_dangerous):
        return ExecuteCommandResult(command=a.command, result=None, message=a.message)
    if a.is_dangerous and a.command != "KEYS":
        return ExecuteCommandResult(command=a.command, result=None, message=a.message)
    if a.need_confirm and not confirm:
        return ExecuteCommandResult(command=a.command, result=None, message=a.message)
    cmd, args = parse_command(payload)
    config = _conn(connection)
    with connect(config, state.safety) as client:
        raw = _execute_command(client, cmd, *args)
    result = _serialize_result(raw)
    return ExecuteCommandResult(command=cmd, result=result, message="已执行。")


# ============== Resources ==============

def _get_state_safe() -> RedisState | None:
    try:
        return mcp.get_context().request_context.lifespan_context
    except Exception:
        return None


@mcp.resource("redis://config")
def resource_config() -> str:
    """当前 Redis 配置与安全策略摘要（不暴露密码）。"""
    state = _get_state_safe()
    if not state:
        return "# 配置信息需在会话中获取。"
    s = state.safety
    lines = [
        "# Redis MCP 配置",
        f"- 默认 profile: {state.default_profile_name}",
        f"- 只读: {s.read_only}",
        f"- max_scan_keys: {s.max_scan_keys}",
        "",
        "## 连接",
    ]
    for k in sorted(state.connection_map):
        c = state.connection_map[k]
        lines.append(f"- {k}: {c.mode} {c.host}:{c.port} {c.description or ''}")
    return "\n".join(lines)


@mcp.resource("redis://keys/{pattern}")
def resource_keys(pattern: str) -> str:
    """指定 pattern 的 key 列表（SCAN，受 max_scan_keys 限制）。"""
    state = _get_state_safe()
    if not state:
        return "(需在会话中加载)"
    config = state.default_connection
    with connect(config, state.safety) as client:
        keys = _list_keys(client, pattern=pattern or "*", max_keys=state.safety.max_scan_keys)
    if not keys:
        return "(无匹配 key)"
    return "\n".join(keys[:200]) + ("\n..." if len(keys) > 200 else "")


# ============== Prompts ==============

@mcp.prompt()
def redis_safe_usage_prompt() -> str:
    """Redis 安全使用习惯"""
    return """使用本 Redis MCP 时请遵守：
1. 先用 list_keys(pattern) 或 redis://keys/* 了解 key 空间，再生成命令。
2. 写命令（SET/DEL/INCR 等）执行前需传入 confirm=true。
3. 禁止通过 MCP 执行 FLUSHALL、FLUSHDB、CONFIG、DEBUG 等危险命令，请在 Redis 客户端中手动操作。
4. 尽量用 SCAN（list_keys）而非 KEYS，避免阻塞。
5. 单条命令由你生成，MCP 只做安全检查与执行。
"""


# ============== 入口 ==============

def main() -> None:
    mcp.run()


if __name__ == "__main__":
    main()
